@@ -50,44 +50,93 @@ X11 / MIT License
 """
 
 import logging
-from privex.loghelper import LogHelper
-
-# Set up logging for the entire module ``privex.helpers`` . Since this is a package, we don't add any
-# console or file logging handlers, we purely just set our minimum logging level to WARNING to avoid
-# spamming the logs of any application importing it.
-def _setup_logging(level=logging.WARNING):
-    lh = LogHelper(__name__, level=level)
-    return lh.get_logger()
-
-log = _setup_logging()
-
-name = 'helpers'
-
-class ImproperlyConfigured(Exception):
-    """Placeholder in-case this fails to import from django.core.exceptions"""
-    pass
-
-class AppRegistryNotReady(Exception):
-    """Placeholder in-case this fails to import from django.core.exceptions"""
-    pass
-
-# Only import the Django functions if Django is actually installed
-try:
-    import django
-    from django.core.exceptions import ImproperlyConfigured, AppRegistryNotReady
-    from privex.helpers.django import *
-except ImportError:
-    log.debug('privex.helpers __init__ failed to import "django", not loading django helpers')
-    pass
-except (ImproperlyConfigured, AppRegistryNotReady):
-    log.debug('privex.helpers __init__ failed to import "django", not loading django helpers')
-    pass
-except Exception:
-    log.debug('privex.helpers __init__ failed to import "django", (unknown exception) not loading django helpers')
-    pass
-
+import warnings
 
 from privex.helpers.common import *
+from privex.helpers.collections import *
 from privex.helpers.decorators import *
 from privex.helpers.net import *
 from privex.helpers.exceptions import *
+from privex.helpers.plugin import *
+from privex.helpers.cache import CacheNotFound, CacheAdapter, CacheWrapper, MemoryCache, cached
+
+from privex.helpers import plugin
+
+log = logging.getLogger(__name__)
+
+
+try:
+    from privex.helpers.cache.RedisCache import RedisCache
+    plugin.HAS_REDIS = True
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "RedisCache", not loading RedisCache')
+
+try:
+    from privex.helpers.cache.asyncx import *
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "cache.asyncx.*", not loading async cache adapters')
+
+try:
+    from privex.helpers.asyncx import *
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "asyncx", not loading async helpers')
+
+try:
+    from privex.helpers.crypto import Format, KeyManager, EncryptHelper, auto_b64decode, is_base64
+    plugin.HAS_CRYPTO = True
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "crypto", not loading cryptography helpers')
+
+try:
+    from privex.helpers.setuppy.common import extras_require, reqs
+    plugin.HAS_SETUPPY_COMMON = True
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "setuppy.common", not loading packaging helpers')
+
+try:
+    from privex.helpers.setuppy.commands import BumpCommand, ExtrasCommand
+    plugin.HAS_SETUPPY_COMMANDS = True
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "setuppy.commands", not loading packaging helpers')
+
+try:
+    from privex.helpers.setuppy.bump import bump_version, get_current_ver
+    plugin.HAS_SETUPPY_BUMP = True
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "setuppy.bump", not loading packaging helpers')
+
+try:
+    from privex.helpers.extras import *
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "extras", cannot load any extras.* modules...')
+
+try:
+    from privex.helpers.converters import *
+except ImportError:
+    log.debug('privex.helpers __init__ failed to import "converter", cannot load any converter.* modules...')
+
+
+def _setup_logging(level=logging.WARNING):
+    """
+    Set up logging for the entire module ``privex.helpers`` . Since this is a package, we don't add any
+    console or file logging handlers, we purely just set our minimum logging level to WARNING to avoid
+    spamming the logs of any application importing it.
+    """
+    try:
+        from privex.loghelper import LogHelper
+        lh = LogHelper(__name__, level=level)
+        return lh.get_logger()
+    except ImportError:
+        warnings.warn(f'{__name__} failed to import privex.loghelper. Logging may not work as expected.')
+        lh = logging.getLogger(__name__)
+        lh.setLevel(logging.WARNING)
+        return log
+    
+
+log = _setup_logging()
+name = 'helpers'
+
+VERSION = '2.9.0'
+
+
+
